@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('acpi', acpi_command_output)
 
-    or
-
-    import jc.parsers.acpi
-    result = jc.parsers.acpi.parse(acpi_command_output)
-
 Schema:
 
     [
