@@ -17,11 +17,6 @@ Usage (module):
     import jc
     result = jc.parse('ini', ini_file_output)
 
-    or
-
-    import jc.parsers.ini
-    result = jc.parsers.ini.parse(ini_file_output)
-
 Schema:
 
     ini or key/value document converted to a dictionary - see the
