@@ -17,11 +17,6 @@ Usage (module):
     import jc
     result = jc.parse('kv', kv_file_output)
 
-    or
-
-    import jc.parsers.kv
-    result = jc.parsers.kv.parse(kv_file_output)
-
 Schema:
 
     key/value document converted to a dictionary - see the
